==> script.module.dandyscrapers-17.11.1.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/wannahd.py <==
import re
from md_request import open_url
import xbmc
import urllib
from ..scraper import Scraper
from ..common import clean_title,clean_search

#CHK _ site not responding, edit get_source at least 3 diff scrapes required!

User_Agent = 'Mozilla/5.0 (iPhone; CPU iPhone OS 8_4 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12H143 Safari/600.1.4'


class wannahd(Scraper):
    domains = ['http://www.wannahd.com']
    name = "WannaHD"
    sources = []

    def __init__(self):
        self.base_link = 'http://www.wannahd.com'
        self.sources = []

    def scrape_movie(self, title, year, imdb, debrid=False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/?s=%s' %(self.base_link,search_id.replace(' ','+'))
            #print 'SEARCH > '+start_url
            headers = {'User_Agent':User_Agent}
            html = open_url(start_url,headers=headers,verify=False,timeout=3).content
            Regex = re.compile('class="image".+?href="(.+?)".+?alt="(.+?)".+?class="year">(.+?)</span>',re.DOTALL).findall(html)
            for item_url,name,date in Regex:
                #print item_url
                #print 'SCRAP_DATE>> '+date
                if clean_title(title).lower() in clean_title(name).lower():
                    if year in date:
                        movie_link = item_url 
                        self.get_source(movie_link)
            return self.sources
        except Exception, argument:
            return self.sources

    def get_source(self,movie_link):
        try:
            #print '::::::::::::xxxxx:::::::::::'+movie_link
            html = open_url(movie_link).content
            sources = re.compile('file:"(.+?)".+?label: \'(.+?)\'',re.DOTALL).findall(html)
            for link,rez in sources:
                self.sources.append({'source': 'Googlelink','quality': rez,'scraper': self.name,'url': link,'direct': False})
        except:
            pass

==> script.module.dandyscrapers-17.11.13.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/wannahd.py <==
import re
from md_request import open_url
import xbmc
import urllib
from ..scraper import Scraper
from ..common import clean_title,clean_search

#CHK _ site not responding, edit get_source at least 3 diff scrapes required!

User_Agent = 'Mozilla/5.0 (iPhone; CPU iPhone OS 8_4 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12H143 Safari/600.1.4'


class wannahd(Scraper):
    domains = ['http://www.wannahd.com']
    name = "WannaHD"
    sources = []

    def __init__(self):
        self.base_link = 'http://www.wannahd.com'
        self.sources = []

    def scrape_movie(self, title, year, imdb, debrid=False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/?s=%s' %(self.base_link,search_id.replace(' ','+'))
            #print 'SEARCH > '+start_url
            headers = {'User_Agent':User_Agent}
            html = open_url(start_url,headers=headers,verify=False,timeout=3).content
            Regex = re.compile('class="image".+?href="(.+?)".+?alt="(.+?)".+?class="year">(.+?)</span>',re.DOTALL).findall(html)
            for item_url,name,date in Regex:
                #print item_url
                #print 'SCRAP_DATE>> '+date
                if clean_title(title).lower() in clean_title(name).lower():
                    if year in date:
                        movie_link = item_url 
                        self.get_source(movie_link)
            return self.sources
        except Exception, argument:
            return self.sources

    def get_source(self,movie_link):
        try:
            #print '::::::::::::xxxxx:::::::::::'+movie_link
            html = open_url(movie_link,timeout=3).content
            sources = re.compile('file:"(.+?)".+?label: \'(.+?)\'',re.DOTALL).findall(html)
            for link,rez in sources:
                self.sources.append({'source': 'Googlelink','quality': rez,'scraper': self.name,'url': link,'direct': False})
        except:
            pass
